.. Xonotic Map Manager Intro

Intro
=====

Xonotic Map Manager is the command-line package manager component of the `xonotic-map-repository`_ project. Whether you're a server admin looking to manage map lists, or a player trying to learn more about their map collection, ``xmm`` is a tool to help you do this quickly and efficiently.


Use it like ``apt``::

    xmm update
    xmm install eggandscrambled.pk3
    xmm list

If you get stuck, try using a ``xmm -h``, or reference the :ref:`Usage` page.

By default, the unofficial, general purpose Xonotic map repository, `xonotic.co`_, is enabled. Advanced users can add additional repositories and/or host their own.

.. _xonotic.co: http://www.xonotic.co
.. _xonotic-map-repository: https://www.github.com/z/xonotic-map-repository

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
